From 3803f0987d7fd38cbd754f3dc37caa29247c852c Mon Sep 17 00:00:00 2001
From: Ariver <shanghai3168@gmail.com>
Date: Wed, 01 Jul 2026 23:21:27 +0800
Subject: [PATCH] Merge Windows preview build

---
 privatevoice.src/scripts/build-release-macos.sh |    8 +++++---
 1 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/privatevoice.src/scripts/build-release-macos.sh b/privatevoice.src/scripts/build-release-macos.sh
index 3f33265..38b0b18 100755
--- a/privatevoice.src/scripts/build-release-macos.sh
+++ b/privatevoice.src/scripts/build-release-macos.sh
@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 #
 # build-release-macos.sh — Build a signed & notarized macOS DMG for PrivateVoice Input
 #
 # Prerequisites (one-time):
 #   1. Install Developer ID certificate in Keychain
@@ -19,8 +19,8 @@
 IDENTITY="Developer ID Application: Ningbo Zhuozhi Innovation Network Technology Co., Ltd. (3HY4G7M2AL)"
 KEYCHAIN_PROFILE="privatevoice"
 
-APP_NAME="PrivateVoice Input"
-BUNDLE_ID="com.privatevoice.input"
+APP_NAME="PrivateVoice Dictation"
+BUNDLE_ID="com.shanghai3168.privatevoicedictation"
 
 SCRIPT_DIR="$(cd "$(dirname "$0")" && pwd)"
 PROJECT_DIR="$(cd "$SCRIPT_DIR/.." && pwd)"
@@ -116,6 +116,8 @@
 cp "$BUILD_DIR/${APP_NAME}"              "$APP_BUNDLE/Contents/MacOS/${APP_NAME}"
 cp "$PROJECT_DIR/build/darwin/icon.icns" \
                                          "$APP_BUNDLE/Contents/Resources/icon.icns"
+find "$PROJECT_DIR/build/darwin" -maxdepth 1 -type d -name "*.lproj" \
+  -exec cp -R {} "$APP_BUNDLE/Contents/Resources/" \;
 
 # Copy dylibs
 cp "$SHERPA_LIB_DIR/libsherpa-onnx-c-api.dylib"   "$APP_BUNDLE/Contents/Frameworks/"
@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 #
-# build-release-macos.sh — Build a signed & notarized macOS DMG for PrivateVoice Input
+# build-release-macos.sh — Build a signed & notarized macOS DMG for PrivateVoice Dictation
 #
 # Prerequisites (one-time):

--
Gitblit v1.9.3